@@ -28,7 +28,7 @@ class Network3Medusa():
                     raw_json=interface
                     print("first")
                     self.add_file_to_hedera(f"{ str(raw_json) },")
-                elif json_dict['TABLE_interface']['ROW_interface'][-1]:
+                elif interface == json_dict['TABLE_interface']['ROW_interface'][-1]:
                     raw_json=interface
                     print("last")
                     self.append_file_to_hedera(str(raw_json))
